summaryrefslogtreecommitdiffstats
path: root/adduser/adduser.sh
diff options
context:
space:
mode:
authorColin Percival <cperciva@FreeBSD.org>2004-03-30 19:24:56 +0000
committerColin Percival <cperciva@FreeBSD.org>2004-03-30 19:24:56 +0000
commit053508780e0afcb1aa53c29eafd8540e0519e6ee (patch)
tree2654e097c7f783c7af55ec87165871d623330eae /adduser/adduser.sh
parentb0e9a82310359965c5d0ede45c75387d33cc3ba5 (diff)
downloadpw-darwin-053508780e0afcb1aa53c29eafd8540e0519e6ee.tar.gz
pw-darwin-053508780e0afcb1aa53c29eafd8540e0519e6ee.tar.zst
pw-darwin-053508780e0afcb1aa53c29eafd8540e0519e6ee.zip
Sychronize with reality: nologin(8) is now in /usr/sbin
Reminded by: trhodes
Diffstat (limited to 'adduser/adduser.sh')
-rw-r--r--adduser/adduser.sh6
1 files changed, 3 insertions, 3 deletions
diff --git a/adduser/adduser.sh b/adduser/adduser.sh
index be779bb..c04463d 100644
--- a/adduser/adduser.sh
+++ b/adduser/adduser.sh
@@ -113,7 +113,7 @@ valid_shells() {
esac
done
# /sbin/nologin is a special case
[ -x "${NOLOGIN_PATH}" ] && echo -n " ${NOLOGIN}"
}
@@ -139,7 +139,7 @@ fullpath_from_shell() {
esac
done
# /sbin/nologin is a special case
if [ "$_shell" = "${NOLOGIN}" ]; then
echo ${NOLOGIN_PATH}
return 0;
@@ -799,7 +799,7 @@ MAILCMD="${MAILCMD:-mail}"
ETCSHELLS="${ETCSHELLS:-/etc/shells}"
NOHOME="/nonexistent"
NOLOGIN="nologin"
-NOLOGIN_PATH="/sbin/nologin"
+NOLOGIN_PATH="/usr/sbin/nologin"
GREPCMD="/usr/bin/grep"
DATECMD="/bin/date"
@@ -113,7 +113,7 @@ valid_shells() {
esac
done
- # /sbin/nologin is a special case
+ # /usr/sbin/nologin is a special case
[ -x "${NOLOGIN_PATH}" ] && echo -n " ${NOLOGIN}"
}
@@ -139,7 +139,7 @@ fullpath_from_shell() {
esac
done
- # /sbin/nologin is a special case
+ # /usr/sbin/nologin is a special case
if [ "$_shell" = "${NOLOGIN}" ]; then
echo ${NOLOGIN_PATH}